@@ -7,7 +7,8 @@
  * Copyright 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,               *
  *           2008, 2009 Alex Martelli                                      *
  *                                                                         *
- * Copyright 2008, 2009, 2010, 2011, 2012, 2013 Case Van Horsen            *
+ * Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014,                     *
+ *           2015 Case Van Horsen                                          *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -427,7 +428,7 @@ mpz_ascii(mpz_t z, int base, int option)
      *                                  -----
      *                                   10
      */
-    size = mpz_sizeinbase(z, base) + 11;
+    size = mpz_sizeinbase(z, (base < 0 ? -base : base)) + 11;
     TEMP_ALLOC(buffer, size);
 
     if (mpz_sgn(z) < 0) {
@@ -2309,7 +2310,7 @@ Pympfr_To_Str(PympfrObject *self)
 {
     PyObject *result, *temp;
     long precision;
-    char fmtstr[30];
+    char fmtstr[60];
 
     precision = (long)(log10(2) * (double)mpfr_get_prec(Pympfr_AS_MPFR(self))) + 2;
 
@@ -2328,7 +2329,7 @@ Pympfr_To_Repr(PympfrObject *self)
 {
     PyObject *result, *temp;
     long precision, bits;
-    char fmtstr[30];
+    char fmtstr[60];
 
     bits = mpfr_get_prec(Pympfr_AS_MPFR(self));
     precision = (long)(log10(2) * (double)bits) + 2;
@@ -2803,7 +2804,7 @@ Pympc_To_Str(PympcObject *self)
     PyObject *result, *temp;
     mpfr_prec_t rbits, ibits;
     long rprec, iprec;
-    char fmtstr[30];
+    char fmtstr[60];
 
     mpc_get_prec2(&rbits, &ibits, Pympc_AS_MPC(self));
     rprec = (long)(log10(2) * (double)rbits) + 2;
@@ -2825,7 +2826,7 @@ Pympc_To_Repr(PympcObject *self)
     PyObject *result, *temp;
     mpfr_prec_t rbits, ibits;
     long rprec, iprec;
-    char fmtstr[30];
+    char fmtstr[60];
 
     mpc_get_prec2(&rbits, &ibits, Pympc_AS_MPC(self));
     rprec = (long)(log10(2) * (double)rbits) + 2;
